@@ -3,7 +3,7 @@
  * iok - Virtual onscreen keyboard for Indic Inscript keymaps.
  *
  * Copyright (C) 2007 Michael Levin <risujin@risujin.org>
- * Copyright (C) 2008-2011 Parag Nemade <panemade@gmail.com>
+ * Copyright (C) 2011-2012 Parag Nemade  <pnemade AT redhat DOT com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -42,6 +42,8 @@ void key_event_cleanup(void);
 void bad_keycodes_write(void);
 void bad_keycodes_read(void);
 
+ GdkDisplay *display;
+   Display *xdisplay;
 
 /*
         X11 KeyCodes
@@ -96,14 +98,14 @@ static void press_keycode(KeyCode k)
 /* Called from various places to generate a key-down event */
 {
     if (k >= key_min && k <= key_max)
-        XTestFakeKeyEvent(GDK_DISPLAY(), k, True, CurrentTime);
+        XTestFakeKeyEvent(xdisplay, k, True, CurrentTime);
 }
 
 static void release_keycode(KeyCode k)
 /* Called from various places to generate a key-up event */
 {
     if (k >= key_min && k <= key_max)
-        XTestFakeKeyEvent(GDK_DISPLAY(), k, False, CurrentTime);
+        XTestFakeKeyEvent(xdisplay, k, False, CurrentTime);
 }
 
 
@@ -165,9 +167,9 @@ static void cleanup_usable(void)
         } else if (usable[i] == KEY_BAD)
             bad++;
     if (freed) {
-        XChangeKeyboardMapping(GDK_DISPLAY(), key_min, key_codes,
+        XChangeKeyboardMapping(xdisplay, key_min, key_codes,
                                keysyms, key_max - key_min + 1);
-        XFlush(GDK_DISPLAY());
+        XFlush(xdisplay);
     }
     g_print("Free'd %d KeyCode(s), %d unused, %d marked bad",
             freed, unused, bad);
@@ -179,7 +181,7 @@ static void release_held_keys(void)
     int i;
     char keys[32];
 
-    XQueryKeymap(GDK_DISPLAY(), keys);
+    XQueryKeymap(xdisplay, keys);
     for (i = 0; i < 32; i++) {
         int j;
 
@@ -216,7 +218,7 @@ static void reset_keyboard(void)
     unsigned int mask;
 
     release_held_keys();
-    XQueryPointer(GDK_DISPLAY(), GDK_WINDOW_XWINDOW(GDK_ROOT_PARENT()),
+    XQueryPointer(xdisplay, GDK_WINDOW_XID(gdk_get_default_root_window ()),
                   &root, &child, &root_x, &root_y, &win_x, &win_y, &mask);
     if (mask & LockMask)
         type_keycode(ke_caps_lock.keycode);
@@ -304,9 +306,9 @@ static void key_event_allocate(KeyEvent *key_event, unsigned int keysym)
     /* Modify the slot to hold our character */
     keysyms[key_offset * key_codes] = keysym;
     keysyms[key_offset * key_codes + 1] = keysym;
-    XChangeKeyboardMapping(GDK_DISPLAY(), key_event->keycode, key_codes,
+    XChangeKeyboardMapping(xdisplay, key_event->keycode, key_codes,
                            keysyms + key_offset * key_codes, 1);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 
 //        g_print("Overwrote KeyCode %d for %s", key_event->keycode,XKeysymToString(keysym));
 }
@@ -366,7 +368,7 @@ void key_event_press(KeyEvent *key_event)
     if (key_event->shift)
         press_keycode(ke_shift.keycode);
     press_keycode(key_event->keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 
 void key_event_release(KeyEvent *key_event)
@@ -389,7 +391,7 @@ void key_event_release(KeyEvent *key_event)
     release_keycode(key_event->keycode);
     if (key_event->shift)
         release_keycode(ke_shift.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 
 #ifdef X_HAVE_UTF8_STRING
@@ -418,7 +420,7 @@ void key_event_send_char(int unichar)
     KeyCode keycode;
 
     /* Get the keycode for an existing key */
-    keycode = XKeysymToKeycode(GDK_DISPLAY(), keysym);
+    keycode = XKeysymToKeycode(display, keysym);
     if (!keycode) {
         g_print("XKeysymToKeycode failed to find KeyCode for '%C'",
                 unichar);
@@ -432,105 +434,105 @@ void key_event_send_char(int unichar)
 void key_event_send_enter()
 {
     type_keycode(ke_enter.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 
 void key_event_send_tab()
 {
     type_keycode(ke_tab.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 
 }
 void key_event_send_space()
 {
     type_keycode(ke_space.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 
 }
 void key_event_send_backspace()
 {
     type_keycode(ke_backspace.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 
 void key_event_send_escape()
 {
     type_keycode(ke_escape.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 
 void key_event_send_f1()
 {
 
     type_keycode(ke_f1.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 
 void key_event_send_f2()
 {
 
     type_keycode(ke_f2.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 void key_event_send_f3()
 {
 
     type_keycode(ke_f3.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 void key_event_send_f4()
 {
 
     type_keycode(ke_f4.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 void key_event_send_f5()
 {
 
     type_keycode(ke_f5.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 void key_event_send_f6()
 {
 
     type_keycode(ke_f6.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 void key_event_send_f7()
 {
 
     type_keycode(ke_f7.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 void key_event_send_f8()
 {
 
     type_keycode(ke_f8.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 void key_event_send_f9()
 {
 
     type_keycode(ke_f9.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 void key_event_send_f10()
 {
 
     type_keycode(ke_f10.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 void key_event_send_f11()
 {
 
     type_keycode(ke_f11.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 void key_event_send_f12()
 {
 
     type_keycode(ke_f12.keycode);
-    XSync(GDK_DISPLAY(), False);
+    XSync(xdisplay, False);
 }
 
 int key_event_init(void)
@@ -541,22 +543,24 @@ int key_event_init(void)
     g_print("Compiled without Unicode support!");
 #endif
 
-    GDK_DISPLAY() = XOpenDisplay( NULL );
-    if ( GDK_DISPLAY() == NULL ) return 1;
+   display = gdk_display_get_default ();
+   xdisplay = GDK_DISPLAY_XDISPLAY (display);
+
+    if ( display == NULL ) return 1;
 
     /* Make sure Xtest is supported */
-    if (!XTestQueryExtension(GDK_DISPLAY(), &a, &b, &c, &d))
+    if (!XTestQueryExtension(xdisplay, &a, &b, &c, &d))
         g_print("Xtest not supported!");
     else
         g_print("Xtest version %d.%d.%d.%d\n", a, b, c, d);
 
     /* Get the keyboard mapping */
-    XDisplayKeycodes(GDK_DISPLAY(), &key_min, &key_max);
-    keysyms = XGetKeyboardMapping(GDK_DISPLAY(), key_min,
+    XDisplayKeycodes(xdisplay, &key_min, &key_max);
+    keysyms = XGetKeyboardMapping(xdisplay, key_min,
                                   key_max - key_min + 1, &key_codes);
 
     /* Get the modifier mapping and variable masks */
-    modmap = XGetModifierMapping(GDK_DISPLAY());
+    modmap = XGetModifierMapping(xdisplay);
     for (i = 0; i < 8; i++)
         for (j = 0; j < modmap->max_keypermod; j++) {
             KeyCode keycode;
